@@ -95,26 +95,33 @@ class RedisHelper:
         """Check key exists in haskey in store"""
         return self.redis_conn.hexists(hashkey, key)
 
-    def redis_hmset(self, *, hashkey: str, dict_obj: dict):
-        """Create or Overwrite dictionary hash store"""
-        for key, val in dict_obj.items():
-            self.redis_hset(hashkey=hashkey, key=key, value=val)
-
-    def redis_hset(self, *, hashkey: str, key: str, value: str):
-        """Create or Overwrite (key, value) pair in hash store"""
-        self.redis_conn.hset(hashkey, key, value)
+    def redis_hset(
+            self,
+            *,
+            hashkey: str,
+            key: str = None,
+            value: str = None,
+            dict_obj: dict = None
+    ):
+        """
+            Create or Overwrite dictionary hash store.
+            Either takes a dict_obj or (key, value) pair.
+        """
+        if dict_obj is not None:
+            self.redis_conn.hset(name=hashkey, mapping=dict_obj)
+        elif key is not None and value is not None:
+            self.redis_conn.hset(name=hashkey, key=key, value=value)
+        else:
+            raise ValueError("Expected either dict_obj or key & value")
 
     def redis_hmget(self, *, hashkey: str, keys: list):
         """Read values for set of keys from hash store"""
-        values = []
-        for k in keys:
-            values.append(self.redis_hget(hashkey=hashkey, key=k))
-        return values
+        return self.redis_conn.hmget(name=hashkey, keys=keys)
 
     def redis_hget(self, *, hashkey: str, key: str):
         """Read values for a given key from hash store"""
-        return self.redis_conn.hget(hashkey, key)
+        return self.redis_conn.hget(name=hashkey, key=key)
 
     def redis_hmgetall(self, *, hashkey: str):
         """Read complete dict object from hash store"""
-        return self.redis_conn.hgetall(hashkey)
+        return self.redis_conn.hgetall(name=hashkey)
